@@ -17,7 +17,7 @@ import torch
 import torch.nn as nn
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision=True, shortcut_features=False):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', shortcut_features_names_saving_suffix = '_shortcut_features_names.npy', shortcut_features_saving_suffix='_shortcut_features.npy', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision=True, shortcut_features=False):
         super().__init__()
         self.supervision_npy_file_suffix=supervision_npy_file_suffix
         self.macro_supervision_npy_file_suffix=macro_supervision_npy_file_suffix
@@ -25,7 +25,8 @@ class AbstractRunner(ABC):
         self.features_names_saving_suffix=features_names_saving_suffix
         self.returns_pkl_file_name=returns_pkl_file_name
         self.local_root_directory=local_root_directory
-        self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
+        self.shortcut_features_saving_suffix = shortcut_features_saving_suffix
+        self.shortcut_features_names_saving_suffix = shortcut_features_names_saving_suffix
         self.shortcut_features = shortcut_features
         self.user=user
         self.n_start = n_start
